@@ -2,6 +2,7 @@ import os
 import posixpath
 import tempfile
 import shutil
+import urllib.parse
 from lxml import etree, html
 from .myzipfile import ZipFile, is_zipfile, ZIP_DEFLATED, ZIP_STORED
 from .utils import xstr
@@ -102,7 +103,7 @@ class Epub2():
             if node is not None:
                 if 'href' in node.attrib: href = node.attrib['href']
                 if 'media-type' in node.attrib: media_type = node.attrib['media-type']
-            if href: data = self._get_file_content(self.content_root + href)
+            if href: data = self._get_file_content(self.content_root + urllib.parse.unquote(href))
         else:
             (href, media_type, data) = self._get_cover_from_first_element()
         return (href, media_type, data)
@@ -113,13 +114,18 @@ class Epub2():
         img_href = None
         data = None
 
-        node = self._get('opf:manifest/opf:item')
-        if node is not None:
-            if 'media-type' in node.attrib: media_type = node.attrib['media-type']
-        if media_type == 'application/xhtml+xml':
+        nodes = self._get_all('opf:manifest/opf:item')
+        for node in nodes:
+            if node is not None:
+                if 'media-type' in node.attrib: 
+                    if node.attrib['media-type'] == 'application/xhtml+xml':
+                        media_type = node.attrib['media-type']
+                        break
+
+        if media_type:
             href = node.attrib['href'] 
             if href:
-                content = self._get_file_content(self.content_root + href)
+                content = self._get_file_content(self.content_root + urllib.parse.unquote(href))
                 tree = html.fromstring(content)
                 nodes = tree.xpath('//img')
                 for node in nodes:
@@ -156,12 +162,13 @@ class Epub2():
 
     def set_author_list(self, author_list):
         node_list = self._get_all('opf:metadata/dc:creator[@opf:role="aut" or not(@opf:role)]')
-        for node in node_list: node.parent().remove(node)
+        for node in node_list: node.getparent().remove(node)
         meta_node = self._get('opf:metadata')
         for author in author_list:
-            node = self._sub_element(meta_node, 'dc:creator')
-            node.attrib['role'] = 'aut'
-            node.text = author
+            if author:
+                node = self._sub_element(meta_node, 'dc:creator')
+                node.attrib['role'] = 'aut'
+                node.text = author
 
     def set_series(self, series):
         node = self._get('opf:metadata/opf:meta[@name="calibre:series"]')
@@ -199,18 +206,20 @@ class Epub2():
         for node in node_list: node.getparent().remove(node)
         meta_node = self._get('opf:metadata')
         for tag in tag_list:
-            node = self._sub_element(meta_node, 'dc:subject')
-            node.text = tag
-            node.tail = '\n'
+            if tag:
+                node = self._sub_element(meta_node, 'dc:subject')
+                node.text = tag
+                node.tail = '\n'
 
     def set_translator_list(self, translator_list):
         node_list = self._get_all('opf:metadata/dc:creator[@opf:role="trl"]')
         for node in node_list: node.getparent().remove(node)
         meta_node = self._get('opf:metadata')
         for translator in translator_list:
-            node = self._sub_element(meta_node, 'dc:creator')
-            node.attrib['role'] = 'trl'
-            node.text = translator
+            if translator:
+                node = self._sub_element(meta_node, 'dc:creator')
+                node.attrib['role'] = 'trl'
+                node.text = translator
 
     def set_cover_data(self, href, media_type, data):
         (href, _, _) = self.get_cover_data()
@@ -231,9 +240,9 @@ class Epub2():
                     dest_zip.writestr(self.opf, etree.tostring(self.tree, encoding='utf-8',
                                       method='xml', xml_declaration=True, pretty_print=True))
 
-                elif f.filename == self.content_root + xstr(self.cover_href):
+                elif f.filename == self.content_root + urllib.parse.unquote(xstr(self.cover_href)):
                     if self.cover_data:
-                        dest_zip.writestr(self.content_root + self.cover_href, self.cover_data)
+                        dest_zip.writestr(self.content_root + urllib.parse.unquote(self.cover_href), self.cover_data)
                 elif f.filename == 'mimetype':
                     buf = src_zip.read(f)
                     dest_zip.writestr(f.filename, buf, ZIP_STORED)
